# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'english_design.ui'
#
# Created by: PyQt5 UI code generator 5.12.1
#
# WARNING! All changes made in this file will be lost!

import json

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        width, height = loadDimensions()
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(width, height)
        MainWindow.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        self.semesters = list()
        self.verticalLayout_15 = QtWidgets.QVBoxLayout()
        self.verticalLayout_15.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.verticalLayout_15.setContentsMargins(-1, 0, 0, -1)
        self.verticalLayout_15.setSpacing(0)
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        self.progress_label_8 = QtWidgets.QLabel(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.progress_label_8.sizePolicy().hasHeightForWidth())
        self.progress_label_8.setSizePolicy(sizePolicy)
        self.progress_label_8.setMaximumSize(QtCore.QSize(600, 16777215))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(13)
        font.setBold(False)
        font.setItalic(False)
        font.setUnderline(True)
        font.setWeight(50)
        self.progress_label_8.setFont(font)
        self.progress_label_8.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.progress_label_8.setStyleSheet("font: 13pt \"Noto Sans\";\n"
                                            "text-decoration: underline;")
        self.progress_label_8.setAlignment(QtCore.Qt.AlignBottom | QtCore.Qt.AlignLeading | QtCore.Qt.AlignLeft)
        self.progress_label_8.setObjectName("progress_label_8")
        self.verticalLayout_15.addWidget(self.progress_label_8)
        self.frame_11 = QtWidgets.QFrame(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_11.sizePolicy().hasHeightForWidth())
        self.frame_11.setSizePolicy(sizePolicy)
        self.frame_11.setMaximumSize(QtCore.QSize(600, 16777215))
        self.frame_11.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_11.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_11.setObjectName("frame_11")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.frame_11)
        self.gridLayout_10.setContentsMargins(0, 2, 0, 4)
        self.gridLayout_10.setHorizontalSpacing(0)
        self.gridLayout_10.setVerticalSpacing(3)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.horizontalLayout_44 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_44.setContentsMargins(0, -1, -1, -1)
        self.horizontalLayout_44.setSpacing(0)
        self.horizontalLayout_44.setObjectName("horizontalLayout_44")
        self.frame = QtWidgets.QFrame(self.frame_11)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setMaximumSize(QtCore.QSize(200, 16777215))
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.frame)
        self.gridLayout_7.setContentsMargins(0, -1, 2, -1)
        self.gridLayout_7.setHorizontalSpacing(2)
        self.gridLayout_7.setVerticalSpacing(6)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.verticalLayout_21 = QtWidgets.QVBoxLayout()
        self.verticalLayout_21.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.verticalLayout_21.setContentsMargins(6, -1, 6, -1)
        self.verticalLayout_21.setSpacing(3)
        self.verticalLayout_21.setObjectName("verticalLayout_21")
        self.desc_label = QtWidgets.QLabel(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.desc_label.sizePolicy().hasHeightForWidth())
        self.desc_label.setSizePolicy(sizePolicy)
        self.desc_label.setMaximumSize(QtCore.QSize(110, 16777215))
        font = QtGui.QFont()
        font.setPointSize(12)
        font.setUnderline(True)
        self.desc_label.setFont(font)
        self.desc_label.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.desc_label.setScaledContents(False)
        self.desc_label.setObjectName("desc_label")
        self.verticalLayout_21.addWidget(self.desc_label)
        self.horizontalLayout_80 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_80.setSpacing(12)
        self.horizontalLayout_80.setObjectName("horizontalLayout_80")
        self.average_in_7 = QtWidgets.QLineEdit(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.average_in_7.sizePolicy().hasHeightForWidth())
        self.average_in_7.setSizePolicy(sizePolicy)
        self.average_in_7.setMaximumSize(QtCore.QSize(60, 16777215))
        self.average_in_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.average_in_7.setText("")
        self.average_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.average_in_7.setReadOnly(True)
        self.average_in_7.setObjectName("average_in_7")
        self.horizontalLayout_80.addWidget(self.average_in_7)
        self.average_lab_7 = QtWidgets.QLabel(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.average_lab_7.sizePolicy().hasHeightForWidth())
        self.average_lab_7.setSizePolicy(sizePolicy)
        self.average_lab_7.setMaximumSize(QtCore.QSize(110, 16777215))
        font = QtGui.QFont()
        # font.setUnderline(True)
        self.average_lab_7.setFont(font)
        self.average_lab_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.average_lab_7.setObjectName("average_lab_7")
        self.horizontalLayout_80.addWidget(self.average_lab_7)
        self.verticalLayout_21.addLayout(self.horizontalLayout_80)
        self.horizontalLayout_81 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_81.setSpacing(12)
        self.horizontalLayout_81.setObjectName("horizontalLayout_81")
        self.points_in_7 = QtWidgets.QLineEdit(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.points_in_7.sizePolicy().hasHeightForWidth())
        self.points_in_7.setSizePolicy(sizePolicy)
        self.points_in_7.setMaximumSize(QtCore.QSize(60, 16777215))
        self.points_in_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.points_in_7.setText("")
        self.points_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.points_in_7.setReadOnly(True)
        self.points_in_7.setObjectName("points_in_7")
        self.horizontalLayout_81.addWidget(self.points_in_7)
        self.points_label_7 = QtWidgets.QLabel(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.points_label_7.sizePolicy().hasHeightForWidth())
        self.points_label_7.setSizePolicy(sizePolicy)
        self.points_label_7.setMaximumSize(QtCore.QSize(110, 16777215))
        font = QtGui.QFont()
        # font.setUnderline(True)
        self.points_label_7.setFont(font)
        self.points_label_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.points_label_7.setObjectName("points_label_7")
        self.horizontalLayout_81.addWidget(self.points_label_7)
        self.verticalLayout_21.addLayout(self.horizontalLayout_81)
        self.horizontalLayout_82 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_82.setSpacing(12)
        self.horizontalLayout_82.setObjectName("horizontalLayout_82")
        self.points_left_in_7 = QtWidgets.QLineEdit(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.points_left_in_7.sizePolicy().hasHeightForWidth())
        self.points_left_in_7.setSizePolicy(sizePolicy)
        self.points_left_in_7.setMaximumSize(QtCore.QSize(60, 16777215))
        self.points_left_in_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.points_left_in_7.setText("")
        self.points_left_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.points_left_in_7.setReadOnly(True)
        self.points_left_in_7.setObjectName("points_left_in_7")
        self.horizontalLayout_82.addWidget(self.points_left_in_7)
        self.points_left_label_7 = QtWidgets.QLabel(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.points_left_label_7.sizePolicy().hasHeightForWidth())
        self.points_left_label_7.setSizePolicy(sizePolicy)
        self.points_left_label_7.setMaximumSize(QtCore.QSize(110, 16777215))
        font = QtGui.QFont()
        # font.setUnderline(True)
        self.points_left_label_7.setFont(font)
        self.points_left_label_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.points_left_label_7.setObjectName("points_left_label_7")
        self.horizontalLayout_82.addWidget(self.points_left_label_7)
        self.verticalLayout_21.addLayout(self.horizontalLayout_82)
        self.horizontalLayout_83 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_83.setSpacing(12)
        self.horizontalLayout_83.setObjectName("horizontalLayout_83")
        self.points_left_to_choose_in_7 = QtWidgets.QLineEdit(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.points_left_to_choose_in_7.sizePolicy().hasHeightForWidth())
        self.points_left_to_choose_in_7.setSizePolicy(sizePolicy)
        self.points_left_to_choose_in_7.setMaximumSize(QtCore.QSize(60, 16777215))
        self.points_left_to_choose_in_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.points_left_to_choose_in_7.setText("")
        self.points_left_to_choose_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.points_left_to_choose_in_7.setReadOnly(True)
        self.points_left_to_choose_in_7.setObjectName("points_left_to_choose_in_7")
        self.horizontalLayout_83.addWidget(self.points_left_to_choose_in_7)
        self.points_left_to_choose_label_7 = QtWidgets.QLabel(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.points_left_to_choose_label_7.sizePolicy().hasHeightForWidth())
        self.points_left_to_choose_label_7.setSizePolicy(sizePolicy)
        self.points_left_to_choose_label_7.setMaximumSize(QtCore.QSize(110, 16777215))
        font = QtGui.QFont()
        # font.setUnderline(True)
        self.points_left_to_choose_label_7.setFont(font)
        self.points_left_to_choose_label_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.points_left_to_choose_label_7.setObjectName("points_left_to_choose_label_7")
        self.horizontalLayout_83.addWidget(self.points_left_to_choose_label_7)
        self.verticalLayout_21.addLayout(self.horizontalLayout_83)
        spacerItem = QtWidgets.QSpacerItem(20, 77, QtWidgets.QSizePolicy.Minimum,
                                           QtWidgets.QSizePolicy.MinimumExpanding)
        self.verticalLayout_21.addItem(spacerItem)
        self.gridLayout_7.addLayout(self.verticalLayout_21, 0, 0, 1, 1)
        self.frame_3 = QtWidgets.QFrame(self.frame_11)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_3.sizePolicy().hasHeightForWidth())
        self.frame_3.setSizePolicy(sizePolicy)
        self.frame_3.setMaximumSize(QtCore.QSize(340, 16777215))
        self.frame_3.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_3.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_3.setObjectName("frame_3")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.frame_3)
        self.gridLayout_8.setContentsMargins(2, -1, 2, -1)
        self.gridLayout_8.setHorizontalSpacing(2)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.verticalLayout_23 = QtWidgets.QVBoxLayout()
        self.verticalLayout_23.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.verticalLayout_23.setSpacing(5)
        self.verticalLayout_23.setObjectName("verticalLayout_23")
        self.horizontalLayout_85 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_85.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout_85.setSpacing(12)
        self.horizontalLayout_85.setObjectName("horizontalLayout_85")
        spacerItem1 = QtWidgets.QSpacerItem(50, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.done_label_7 = QtWidgets.QLabel(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.done_label_7.sizePolicy().hasHeightForWidth())
        self.done_label_7.setSizePolicy(sizePolicy)
        self.done_label_7.setMaximumSize(QtCore.QSize(110, 16777215))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        font.setBold(False)
        font.setItalic(False)
        font.setUnderline(True)
        font.setWeight(7)
        self.done_label_7.setFont(font)
        self.done_label_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.done_label_7.setStyleSheet("font: 57 10pt \"Noto Sans\";")
        self.done_label_7.setObjectName("done_label_7")
        self.of_label_7 = QtWidgets.QLabel(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.of_label_7.sizePolicy().hasHeightForWidth())
        self.of_label_7.setSizePolicy(sizePolicy)
        self.of_label_7.setMaximumSize(QtCore.QSize(110, 16777215))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        font.setBold(False)
        font.setItalic(False)
        font.setUnderline(True)
        font.setWeight(7)
        self.of_label_7.setFont(font)
        self.of_label_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.of_label_7.setStyleSheet("font: 57 10pt \"Noto Sans\";")
        self.of_label_7.setObjectName("of_label_7")
        self.horizontalLayout_85.addWidget(self.of_label_7)
        self.horizontalLayout_85.addItem(spacerItem1)
        self.horizontalLayout_85.addWidget(self.done_label_7)
        spacerItem2 = QtWidgets.QSpacerItem(150, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_85.addItem(spacerItem2)
        self.verticalLayout_23.addLayout(self.horizontalLayout_85)
        self.horizontalLayout_92 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_92.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.horizontalLayout_92.setSpacing(12)
        self.horizontalLayout_92.setObjectName("horizontalLayout_92")
        self.must_of_in = QtWidgets.QDoubleSpinBox(self.frame_3)
        self.must_of_in.setRange(0, 1000)
        self.must_of_in.setDecimals(1)
        self.must_of_in.setSingleStep(0.5)
        self.must_of_in.setAlignment(QtCore.Qt.AlignCenter)
        self.must_of_in.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.must_of_in.sizePolicy().hasHeightForWidth())
        self.must_of_in.setSizePolicy(sizePolicy)
        self.must_of_in.setMaximumSize(QtCore.QSize(75, 16777215))
        self.must_of_in.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.must_of_in.setAlignment(QtCore.Qt.AlignCenter)
        self.must_of_in.setObjectName("must_of_in")
        self.horizontalLayout_92.addWidget(self.must_of_in)
        self.must_done_in = QtWidgets.QLineEdit(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.must_done_in.sizePolicy().hasHeightForWidth())
        self.must_done_in.setSizePolicy(sizePolicy)
        self.must_done_in.setMaximumSize(QtCore.QSize(75, 16777215))
        self.must_done_in.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.must_done_in.setText("")
        self.must_done_in.setAlignment(QtCore.Qt.AlignCenter)
        self.must_done_in.setReadOnly(True)
        self.must_done_in.setObjectName("must_done_in")
        self.horizontalLayout_92.addWidget(self.must_done_in)
        self.must_label = QtWidgets.QLabel(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.must_label.sizePolicy().hasHeightForWidth())
        self.must_label.setSizePolicy(sizePolicy)
        self.must_label.setMaximumSize(QtCore.QSize(110, 16777215))
        font = QtGui.QFont()
        # font.setUnderline(True)
        self.must_label.setFont(font)
        self.must_label.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.must_label.setObjectName("must_label")
        self.horizontalLayout_92.addWidget(self.must_label)
        self.verticalLayout_23.addLayout(self.horizontalLayout_92)
        self.horizontalLayout_86 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_86.setSpacing(12)
        self.horizontalLayout_86.setObjectName("horizontalLayout_86")
        self.list_a_of_in_7 = QtWidgets.QDoubleSpinBox(self.frame_3)
        self.list_a_of_in_7.setRange(0, 1000)
        self.list_a_of_in_7.setDecimals(1)
        self.list_a_of_in_7.setSingleStep(0.5)
        self.list_a_of_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.list_a_of_in_7.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.list_a_of_in_7.sizePolicy().hasHeightForWidth())
        self.list_a_of_in_7.setSizePolicy(sizePolicy)
        self.list_a_of_in_7.setMaximumSize(QtCore.QSize(75, 16777215))
        self.list_a_of_in_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.list_a_of_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.list_a_of_in_7.setObjectName("list_a_of_in_7")
        self.horizontalLayout_86.addWidget(self.list_a_of_in_7)
        self.list_a_done_in_7 = QtWidgets.QLineEdit(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.list_a_done_in_7.sizePolicy().hasHeightForWidth())
        self.list_a_done_in_7.setSizePolicy(sizePolicy)
        self.list_a_done_in_7.setMaximumSize(QtCore.QSize(75, 16777215))
        self.list_a_done_in_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.list_a_done_in_7.setText("")
        self.list_a_done_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.list_a_done_in_7.setReadOnly(True)
        self.list_a_done_in_7.setObjectName("list_a_done_in_7")
        self.horizontalLayout_86.addWidget(self.list_a_done_in_7)
        self.list_a_label_7 = QtWidgets.QLabel(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.list_a_label_7.sizePolicy().hasHeightForWidth())
        self.list_a_label_7.setSizePolicy(sizePolicy)
        self.list_a_label_7.setMaximumSize(QtCore.QSize(110, 16777215))
        font = QtGui.QFont()
        # font.setUnderline(True)
        self.list_a_label_7.setFont(font)
        self.list_a_label_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.list_a_label_7.setObjectName("list_a_label_7")
        self.horizontalLayout_86.addWidget(self.list_a_label_7)
        self.verticalLayout_23.addLayout(self.horizontalLayout_86)
        self.horizontalLayout_87 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_87.setSpacing(12)
        self.horizontalLayout_87.setObjectName("horizontalLayout_87")
        self.list_b_of_in_7 = QtWidgets.QDoubleSpinBox(self.frame_3)
        self.list_b_of_in_7.setRange(0, 1000)
        self.list_b_of_in_7.setDecimals(1)
        self.list_b_of_in_7.setSingleStep(0.5)
        self.list_b_of_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.list_b_of_in_7.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.list_b_of_in_7.sizePolicy().hasHeightForWidth())
        self.list_b_of_in_7.setSizePolicy(sizePolicy)
        self.list_b_of_in_7.setMaximumSize(QtCore.QSize(75, 16777215))
        self.list_b_of_in_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.list_b_of_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.list_b_of_in_7.setObjectName("list_b_of_in_7")
        self.horizontalLayout_87.addWidget(self.list_b_of_in_7)
        self.list_b_done_in_7 = QtWidgets.QLineEdit(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.list_b_done_in_7.sizePolicy().hasHeightForWidth())
        self.list_b_done_in_7.setSizePolicy(sizePolicy)
        self.list_b_done_in_7.setMaximumSize(QtCore.QSize(75, 16777215))
        self.list_b_done_in_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.list_b_done_in_7.setText("")
        self.list_b_done_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.list_b_done_in_7.setReadOnly(True)
        self.list_b_done_in_7.setObjectName("list_b_done_in_7")
        self.horizontalLayout_87.addWidget(self.list_b_done_in_7)
        self.list_b_label_7 = QtWidgets.QLabel(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.list_b_label_7.sizePolicy().hasHeightForWidth())
        self.list_b_label_7.setSizePolicy(sizePolicy)
        self.list_b_label_7.setMaximumSize(QtCore.QSize(110, 16777215))
        font = QtGui.QFont()
        # font.setUnderline(True)
        self.list_b_label_7.setFont(font)
        self.list_b_label_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.list_b_label_7.setObjectName("list_b_label_7")
        self.horizontalLayout_87.addWidget(self.list_b_label_7)
        self.verticalLayout_23.addLayout(self.horizontalLayout_87)
        self.horizontalLayout_94 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_94.setSpacing(12)
        self.horizontalLayout_94.setObjectName("horizontalLayout_94")
        self.malag_of_in = QtWidgets.QDoubleSpinBox(self.frame_3)
        self.malag_of_in.setRange(0, 1000)
        self.malag_of_in.setDecimals(1)
        self.malag_of_in.setSingleStep(0.5)
        self.malag_of_in.setAlignment(QtCore.Qt.AlignCenter)
        self.malag_of_in.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.malag_of_in.sizePolicy().hasHeightForWidth())
        self.malag_of_in.setSizePolicy(sizePolicy)
        self.malag_of_in.setMaximumSize(QtCore.QSize(75, 16777215))
        self.malag_of_in.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.malag_of_in.setAlignment(QtCore.Qt.AlignCenter)
        self.malag_of_in.setObjectName("malag_of_in")
        self.horizontalLayout_94.addWidget(self.malag_of_in)
        self.malag_done_in = QtWidgets.QLineEdit(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.malag_done_in.sizePolicy().hasHeightForWidth())
        self.malag_done_in.setSizePolicy(sizePolicy)
        self.malag_done_in.setMaximumSize(QtCore.QSize(75, 16777215))
        self.malag_done_in.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.malag_done_in.setText("")
        self.malag_done_in.setAlignment(QtCore.Qt.AlignCenter)
        self.malag_done_in.setReadOnly(True)
        self.malag_done_in.setObjectName("malag_done_in")
        self.horizontalLayout_94.addWidget(self.malag_done_in)
        self.malag_label_7 = QtWidgets.QLabel(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.malag_label_7.sizePolicy().hasHeightForWidth())
        self.malag_label_7.setSizePolicy(sizePolicy)
        self.malag_label_7.setMaximumSize(QtCore.QSize(110, 16777215))
        self.malag_label_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.malag_label_7.setFont(font)
        self.malag_label_7.setObjectName("malag_label_7")
        self.horizontalLayout_94.addWidget(self.malag_label_7)
        self.verticalLayout_23.addLayout(self.horizontalLayout_94)
        self.horizontalLayout_90 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_90.setSpacing(12)
        self.horizontalLayout_90.setObjectName("horizontalLayout_90")
        self.free_of_in_7 = QtWidgets.QDoubleSpinBox(self.frame_3)
        self.free_of_in_7.setRange(0, 1000)
        self.free_of_in_7.setDecimals(1)
        self.free_of_in_7.setSingleStep(0.5)
        self.free_of_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.free_of_in_7.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.free_of_in_7.sizePolicy().hasHeightForWidth())
        self.free_of_in_7.setSizePolicy(sizePolicy)
        self.free_of_in_7.setMaximumSize(QtCore.QSize(75, 16777215))
        self.free_of_in_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.free_of_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.free_of_in_7.setObjectName("free_of_in_7")
        self.horizontalLayout_90.addWidget(self.free_of_in_7)
        self.free_done_in_7 = QtWidgets.QLineEdit(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.free_done_in_7.sizePolicy().hasHeightForWidth())
        self.free_done_in_7.setSizePolicy(sizePolicy)
        self.free_done_in_7.setMaximumSize(QtCore.QSize(75, 16777215))
        self.free_done_in_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.free_done_in_7.setText("")
        self.free_done_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.free_done_in_7.setReadOnly(True)
        self.free_done_in_7.setObjectName("free_done_in_7")
        self.horizontalLayout_90.addWidget(self.free_done_in_7)
        self.free_label_7 = QtWidgets.QLabel(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.free_label_7.sizePolicy().hasHeightForWidth())
        self.free_label_7.setSizePolicy(sizePolicy)
        self.free_label_7.setMaximumSize(QtCore.QSize(110, 16777215))
        self.free_label_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.free_label_7.setFont(font)
        self.free_label_7.setObjectName("free_label_7")
        self.horizontalLayout_90.addWidget(self.free_label_7)
        self.verticalLayout_23.addLayout(self.horizontalLayout_90)
        self.horizontalLayout_88 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_88.setSpacing(12)
        self.horizontalLayout_88.setObjectName("horizontalLayout_88")
        self.project_of_in_7 = QtWidgets.QDoubleSpinBox(self.frame_3)
        self.project_of_in_7.setRange(0, 1000)
        self.project_of_in_7.setDecimals(1)
        self.project_of_in_7.setSingleStep(0.5)
        self.project_of_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.project_of_in_7.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.project_of_in_7.sizePolicy().hasHeightForWidth())
        self.project_of_in_7.setSizePolicy(sizePolicy)
        self.project_of_in_7.setMaximumSize(QtCore.QSize(75, 16777215))
        self.project_of_in_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.project_of_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.project_of_in_7.setObjectName("project_of_in_7")
        self.horizontalLayout_88.addWidget(self.project_of_in_7)
        self.project_done_in_7 = QtWidgets.QLineEdit(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.project_done_in_7.sizePolicy().hasHeightForWidth())
        self.project_done_in_7.setSizePolicy(sizePolicy)
        self.project_done_in_7.setMaximumSize(QtCore.QSize(75, 16777215))
        self.project_done_in_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.project_done_in_7.setText("")
        self.project_done_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.project_done_in_7.setReadOnly(True)
        self.project_done_in_7.setObjectName("project_done_in_7")
        self.horizontalLayout_88.addWidget(self.project_done_in_7)
        self.project_label_7 = QtWidgets.QLabel(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.project_label_7.sizePolicy().hasHeightForWidth())
        self.project_label_7.setSizePolicy(sizePolicy)
        self.project_label_7.setMaximumSize(QtCore.QSize(110, 16777215))
        font = QtGui.QFont()
        # font.setUnderline(True)
        self.project_label_7.setFont(font)
        self.project_label_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.project_label_7.setObjectName("project_label_7")
        self.horizontalLayout_88.addWidget(self.project_label_7)
        self.verticalLayout_23.addLayout(self.horizontalLayout_88)
        self.horizontalLayout_89 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_89.setSpacing(12)
        self.horizontalLayout_89.setObjectName("horizontalLayout_89")
        self.sport_of_in_7 = QtWidgets.QDoubleSpinBox(self.frame_3)
        self.sport_of_in_7.setRange(0, 1000)
        self.sport_of_in_7.setDecimals(1)
        self.sport_of_in_7.setSingleStep(0.5)
        self.sport_of_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.sport_of_in_7.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sport_of_in_7.sizePolicy().hasHeightForWidth())
        self.sport_of_in_7.setSizePolicy(sizePolicy)
        self.sport_of_in_7.setMaximumSize(QtCore.QSize(75, 16777215))
        self.sport_of_in_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.sport_of_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.sport_of_in_7.setToolTip("* Sport is a part of mandatory courses")
        self.sport_of_in_7.setObjectName("sport_of_in_7")
        self.horizontalLayout_89.addWidget(self.sport_of_in_7)
        self.sport_done_in_7 = QtWidgets.QLineEdit(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sport_done_in_7.sizePolicy().hasHeightForWidth())
        self.sport_done_in_7.setSizePolicy(sizePolicy)
        self.sport_done_in_7.setMaximumSize(QtCore.QSize(75, 16777215))
        self.sport_done_in_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.sport_done_in_7.setText("")
        self.sport_done_in_7.setAlignment(QtCore.Qt.AlignCenter)
        self.sport_done_in_7.setReadOnly(True)
        self.sport_done_in_7.setObjectName("sport_done_in_7")
        self.horizontalLayout_89.addWidget(self.sport_done_in_7)
        self.sport_label_7 = QtWidgets.QLabel(self.frame_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sport_label_7.sizePolicy().hasHeightForWidth())
        self.sport_label_7.setSizePolicy(sizePolicy)
        self.sport_label_7.setMaximumSize(QtCore.QSize(110, 16777215))
        self.sport_label_7.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.sport_label_7.setFont(font)
        self.sport_label_7.setObjectName("sport_label_7")
        self.horizontalLayout_89.addWidget(self.sport_label_7)
        self.verticalLayout_23.addLayout(self.horizontalLayout_89)
        self.horizontalLayout_91 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_91.setSpacing(12)
        self.horizontalLayout_91.setObjectName("horizontalLayout_91")
        spacerItem3 = QtWidgets.QSpacerItem(124, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_91.addItem(spacerItem3)
        self.english_checkbox_7 = QtWidgets.QCheckBox(self.frame_3)
        self.english_checkbox_7.setMaximumSize(QtCore.QSize(190, 16777215))
        self.english_checkbox_7.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.english_checkbox_7.setObjectName("english_checkbox_7")
        self.horizontalLayout_91.addWidget(self.english_checkbox_7)
        self.verticalLayout_23.addLayout(self.horizontalLayout_91)
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_23.addItem(spacerItem4)
        self.gridLayout_8.addLayout(self.verticalLayout_23, 0, 0, 1, 1)
        self.horizontalLayout_44.addWidget(self.frame_3)
        self.horizontalLayout_44.addWidget(self.frame)
        self.gridLayout_10.addLayout(self.horizontalLayout_44, 1, 0, 1, 1)
        self.horizontalLayout_93 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_93.setSpacing(0)
        self.horizontalLayout_93.setObjectName("horizontalLayout_93")
        self.horizontalLayout_45 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_45.setSpacing(7)
        self.horizontalLayout_45.setObjectName("horizontalLayout_45")
        spacerItem5 = QtWidgets.QSpacerItem(490, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_45.addItem(spacerItem5)
        self.deg_points_in = QtWidgets.QDoubleSpinBox(self.frame_11)
        self.deg_points_in.setRange(0, 1000)
        self.deg_points_in.setDecimals(1)
        self.deg_points_in.setSingleStep(0.5)
        self.deg_points_in.setAlignment(QtCore.Qt.AlignCenter)
        self.deg_points_in.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.deg_points_in.sizePolicy().hasHeightForWidth())
        self.deg_points_in.setSizePolicy(sizePolicy)
        self.deg_points_in.setMaximumSize(QtCore.QSize(75, 16777215))
        self.deg_points_in.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.deg_points_in.setAlignment(QtCore.Qt.AlignCenter)
        self.deg_points_in.setReadOnly(False)
        self.deg_points_in.setObjectName("deg_points_in")
        self.horizontalLayout_45.addWidget(self.deg_points_in)
        self.deg_points_label = QtWidgets.QLabel(self.frame_11)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.deg_points_label.sizePolicy().hasHeightForWidth())
        self.deg_points_label.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setUnderline(True)
        self.deg_points_label.setFont(font)
        self.deg_points_label.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.deg_points_label.setObjectName("deg_points_label")
        self.horizontalLayout_45.addWidget(self.deg_points_label)
        self.horizontalLayout_93.addLayout(self.horizontalLayout_45)
        spacerItem6 = QtWidgets.QSpacerItem(21, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_93.addItem(spacerItem6)
        self.gridLayout_10.addLayout(self.horizontalLayout_93, 0, 0, 1, 1)
        self.verticalLayout_15.addWidget(self.frame_11)
        self.horizontalLayout_22.addLayout(self.verticalLayout_15)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.courses_tab_widget = QtWidgets.QTabWidget(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding,
                                           QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.courses_tab_widget.sizePolicy().hasHeightForWidth())
        self.courses_tab_widget.setSizePolicy(sizePolicy)
        self.courses_tab_widget.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.courses_tab_widget.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.courses_tab_widget.setTabsClosable(True)
        self.courses_tab_widget.setObjectName("courses_tab_widget")

        self.horizontalLayout.addWidget(self.courses_tab_widget)
        self.horizontalLayout_22.addLayout(self.horizontalLayout)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("images/list-add.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.add_semester_but = QtWidgets.QPushButton(self.centralwidget)
        self.add_semester_but.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.add_semester_but.setIcon(icon1)
        self.add_semester_but.setObjectName("add_semester_but")
        self.add_semester_but.setToolTip("Add semester")
        self.courses_tab_widget.setCornerWidget(self.add_semester_but)
        # self.verticalLayout_4.addWidget(self.add_semester_but)
        self.gridLayout_3.addLayout(self.horizontalLayout_22, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1589, 36))
        self.menubar.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.menubar.setObjectName("menubar")
        self.menu = QtWidgets.QMenu(self.menubar)
        self.menu.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.menu.setObjectName("menu")
        self.menu_2 = QtWidgets.QMenu(self.menubar)
        self.menu_2.setObjectName("menu_2")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionNew = QtWidgets.QAction(MainWindow)
        self.actionNew.setObjectName("actionNew")
        self.actionLoadTemplate = QtWidgets.QAction(MainWindow)
        self.actionLoadTemplate.setObjectName("actionLoadTemplate")
        self.actionSave = QtWidgets.QAction(MainWindow)
        self.actionSave.setObjectName("actionSave")
        self.actionUpdate_Courses_DB = QtWidgets.QAction(MainWindow)
        self.actionUpdate_Courses_DB.setObjectName("actionUpdate_Courses_DB")
        self.action = QtWidgets.QAction(MainWindow)
        self.action.setObjectName("action")
        self.actionEnglish = QtWidgets.QAction(MainWindow)
        self.actionEnglish.setObjectName("actionEnglish")
        self.actionHeb = QtWidgets.QAction(MainWindow)
        self.actionHeb.setObjectName("actionInfo")
        self.actionNew = QtWidgets.QAction(MainWindow)
        self.actionNew.setObjectName("actionNew")
        self.actionSave = QtWidgets.QAction(MainWindow)
        self.actionSave.setObjectName("actionSave")
        self.actionSaveAs = QtWidgets.QAction(MainWindow)
        self.actionSaveAs.setObjectName("actionSaveAs")
        self.actionLoad = QtWidgets.QAction(MainWindow)
        self.actionLoad.setObjectName("actionLoad")
        self.actionUpdate_Courses_DB = QtWidgets.QAction(MainWindow)
        self.actionUpdate_Courses_DB.setObjectName("actionUpdate_Courses_DB")
        self.actionInfo = QtWidgets.QAction(MainWindow)
        self.actionInfo.setObjectName("actionInfo")
        self.actionNew.setShortcut("CTRL+N")
        self.actionLoadTemplate.setShortcut("CTRL+SHIFT+T")
        self.actionSave.setShortcut("CTRL+S")
        self.actionSaveAs.setShortcut("CTRL+SHIFT+S")
        self.actionLoad.setShortcut("CTRL+O")
        self.menu.addAction(self.actionNew)
        self.menu.addAction(self.actionSave)
        self.menu.addAction(self.actionSaveAs)
        self.menu.addAction(self.actionLoad)
        self.menu.addAction(self.actionLoadTemplate)
        self.menu.addSeparator()
        self.menu.addAction(self.actionUpdate_Courses_DB)
        self.menu.addAction(self.actionInfo)
        self.menu_2.addAction(self.actionEnglish)
        self.menu_2.addAction(self.actionHeb)
        self.menubar.addAction(self.menu.menuAction())
        self.menubar.addAction(self.menu_2.menuAction())

        self.retranslateUi(MainWindow)
        self.courses_tab_widget.setCurrentIndex(0)
        self.add_semester_but.clicked.connect(self.courses_tab_widget.update)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.deg_points_in, self.add_semester_but)
        MainWindow.setTabOrder(self.sport_done_in_7, self.project_done_in_7)
        MainWindow.setTabOrder(self.project_done_in_7, self.must_done_in)
        MainWindow.setTabOrder(self.must_done_in, self.list_a_done_in_7)
        MainWindow.setTabOrder(self.list_a_done_in_7, self.average_in_7)
        MainWindow.setTabOrder(self.average_in_7, self.points_in_7)
        MainWindow.setTabOrder(self.points_in_7, self.points_left_in_7)
        MainWindow.setTabOrder(self.points_left_in_7, self.points_left_to_choose_in_7)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Degree Planer"))
        self.progress_label_8.setText(_translate("MainWindow", "Degree progress summary:"))
        self.desc_label.setText(_translate("MainWindow", "Summary:"))
        self.average_lab_7.setText(_translate("MainWindow", "Average:"))
        self.points_label_7.setText(_translate("MainWindow", "Points done:"))
        self.points_left_label_7.setText(_translate("MainWindow", "Points left:"))
        self.points_left_to_choose_label_7.setText(_translate("MainWindow", "Not chosen:"))
        self.done_label_7.setText(_translate("MainWindow", "Left:"))
        self.of_label_7.setToolTip(
            _translate("MainWindow", "<html><head/><body><p>You have to fill this column.</p></body></html>"))
        self.of_label_7.setText(_translate("MainWindow", "Of:"))
        self.must_of_in.setValue(0)
        self.must_label.setText(_translate("MainWindow", "Mandatory:"))
        self.list_a_of_in_7.setValue(0)
        self.list_a_label_7.setText(_translate("MainWindow", "A\' list:"))
        self.list_b_of_in_7.setValue(0)
        self.list_b_label_7.setText(_translate("MainWindow", "B\' list:"))
        self.malag_of_in.setValue(0)
        self.malag_label_7.setText(_translate("MainWindow", "Humanities:"))
        self.free_of_in_7.setValue(0)
        self.free_label_7.setText(_translate("MainWindow", "Free choice:"))
        self.project_of_in_7.setValue(0)
        self.project_label_7.setText(_translate("MainWindow", "Projects:"))
        self.sport_of_in_7.setValue(0)
        self.sport_label_7.setText(_translate("MainWindow", "Sport:"))
        self.english_checkbox_7.setText(_translate("MainWindow", "English\'s Exemption:"))
        self.deg_points_in.setValue(0)
        self.deg_points_label.setToolTip(_translate("MainWindow", "<html><head/><body><p>Fill!</p></body></html>"))
        self.deg_points_label.setText(_translate("MainWindow", "Degree\'s points:"))
        self.menu.setTitle(_translate("MainWindow", "Menu"))
        self.menu_2.setTitle(_translate("MainWindow", "Language"))
        self.actionEnglish.setText(_translate("MainWindow", "English"))
        self.actionHeb.setText(_translate("MainWindow", "עברית"))
        self.actionNew.setText(_translate("MainWindow", "New"))
        self.actionSave.setText(_translate("MainWindow", "Save"))
        self.actionSaveAs.setText(_translate("MainWindow", "Save As"))
        self.actionLoad.setText(_translate("MainWindow", "Load"))
        self.actionLoadTemplate.setText(_translate("MainWindow", "Load Template"))
        self.actionUpdate_Courses_DB.setText(_translate("MainWindow", "Update Courses"))
        self.actionInfo.setText(_translate("MainWindow", "Info"))


def loadDimensions():
    with open("settings.json", "r") as read_file:
        data = json.load(read_file)
        width = data['dimensions'][0]['width']
        height = data['dimensions'][0]['height']
        return width, height
    return 1320, 565
